==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.md <==
# AmazonCloudSearchSearchDocuments


```text
aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments
```

```text
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')
```



| Illustration | AmazonCloudSearchSearchDocuments | AmazonCloudSearchSearchDocumentsCard | AmazonCloudSearchSearchDocumentsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.png) | ![illustration for AmazonCloudSearchSearchDocuments](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.Local.png) | ![illustration for AmazonCloudSearchSearchDocumentsCard](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocumentsCard.Local.png) | ![illustration for AmazonCloudSearchSearchDocumentsGroup](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocumentsGroup.Local.png) |




## AmazonCloudSearchSearchDocuments

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocuments
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocuments('AmazonCloudSearchSearchDocuments', 'Amazon Cloud Search Search Documents', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocuments
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocuments('AmazonCloudSearchSearchDocuments', 'Amazon Cloud Search Search Documents', 'an optional tech label')
@enduml
```

## AmazonCloudSearchSearchDocumentsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsCard
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsCard('AmazonCloudSearchSearchDocumentsCard', 'Amazon Cloud Search Search Documents Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsCard
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsCard('AmazonCloudSearchSearchDocumentsCard', 'Amazon Cloud Search Search Documents Card', 'an optional description')
@enduml
```

## AmazonCloudSearchSearchDocumentsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsGroup
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsGroup('AmazonCloudSearchSearchDocumentsGroup', 'Amazon Cloud Search Search Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsGroup
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsGroup('AmazonCloudSearchSearchDocumentsGroup', 'Amazon Cloud Search Search Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.md <==
# AmazonCloudSearchSearchDocuments


```text
aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments
```

```text
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')
```



| Illustration | AmazonCloudSearchSearchDocuments | AmazonCloudSearchSearchDocumentsCard | AmazonCloudSearchSearchDocumentsGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.png) | ![illustration for AmazonCloudSearchSearchDocuments](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments.Local.png) | ![illustration for AmazonCloudSearchSearchDocumentsCard](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocumentsCard.Local.png) | ![illustration for AmazonCloudSearchSearchDocumentsGroup](../../../aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocumentsGroup.Local.png) |




## AmazonCloudSearchSearchDocuments

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocuments
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocuments('AmazonCloudSearchSearchDocuments', 'Amazon Cloud Search Search Documents', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocuments
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocuments('AmazonCloudSearchSearchDocuments', 'Amazon Cloud Search Search Documents', 'an optional tech label')
@enduml
```

## AmazonCloudSearchSearchDocumentsCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsCard
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsCard('AmazonCloudSearchSearchDocumentsCard', 'Amazon Cloud Search Search Documents Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsCard
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsCard('AmazonCloudSearchSearchDocumentsCard', 'Amazon Cloud Search Search Documents Card', 'an optional description')
@enduml
```

## AmazonCloudSearchSearchDocumentsGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsGroup
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsGroup('AmazonCloudSearchSearchDocumentsGroup', 'Amazon Cloud Search Search Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonCloudSearchSearchDocumentsGroup
include('aws-20210730/Resource/Analytics/AmazonCloudSearchSearchDocuments')

' renders the element
AmazonCloudSearchSearchDocumentsGroup('AmazonCloudSearchSearchDocumentsGroup', 'Amazon Cloud Search Search Documents Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
